========
loomsitu
========


.. image:: https://img.shields.io/pypi/v/loomsitu.svg
        :target: https://pypi.python.org/pypi/loomsitu

.. image:: https://img.shields.io/travis/m3works/loomsitu.svg
        :target: https://travis-ci.com/m3works/loomsitu

.. image:: https://readthedocs.org/projects/loomsitu/badge/?version=latest
        :target: https://loomsitu.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Manage reading and analyzing raw files of insitu data. The goal is to get
raw insitu data files into manageable classes with helpful functions and provide
access to the data as GeoPandas Arrays.

The first application of this will be for SnowEx pit data.

THIS IS A WORK IN PROGRESS (use at your own risk as outlined in the MIT license). We
fully welcome any contribution and ideas. Snow science works better together!


* Free software: MIT license
* Documentation: https://loomsitu.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
